@@ -23,7 +23,7 @@ class ClinicalQualityMeasure123v6Test(SDKBaseTest):
         self.assertEqual(expected, ClinicalQualityMeasure123v6._meta.description)
 
     def test_information(self):
-        expected = 'https://ecqi.healthit.gov/ecqm/measures/cms123v6'
+        expected = 'https://ecqi.healthit.gov/sites/default/files/ecqm/measures/CMS123v6.html'
         self.assertEqual(expected, ClinicalQualityMeasure123v6._meta.information)
 
     def test_enabled(self):
