@@ -708,6 +708,19 @@ class PrescriptionRecordSet(PatientRecordSet):
         return item['coding']
 
 
+class ProcedureRecordSet(PatientRecordSet):
+    VALID_SYSTEMS = [
+        'cpt',
+        'snomedct'
+    ]
+    PATIENT_FIELD = 'procedures'
+    API_UPDATE_FIELD = 'procedures'
+
+    @staticmethod
+    def item_to_codes(item) -> List:
+        return item['coding']
+
+
 class ProtocolOverrideRecordSet(PatientRecordSet):
     VALID_SYSTEMS: List[str] = ['snomedct']
     PATIENT_FIELD = 'protocol_overrides'
