@@ -31,6 +31,7 @@ class TestPatient(SDKBaseTest):
             'interviews',
             'lab_reports',
             'medications',
+            'procedures',
             'protocol_overrides',
             'prescriptions',
             'referral_reports',
@@ -54,6 +55,7 @@ class TestPatient(SDKBaseTest):
             'interviews': 1,
             'lab_reports': 1,
             'medications': 1,
+            'procedures': 0,
             'protocol_overrides': 0,
             'prescriptions': 0,
             'referral_reports': 0,
@@ -80,6 +82,7 @@ class TestPatient(SDKBaseTest):
             'interviews': 2,
             'lab_reports': 2,
             'medications': 2,
+            'procedures': 1,
             'protocol_overrides': 2,
             'prescriptions': 1,
             'referral_reports': 1,
@@ -106,6 +109,7 @@ class TestPatient(SDKBaseTest):
             'InterviewRecordSet',
             'LabReportRecordSet',
             'MedicationRecordSet',
+            'ProcedureRecordSet',
             'ProtocolOverrideRecordSet',
             'PrescriptionRecordSet',
             'ReasonForVisitRecordSet',
@@ -136,6 +140,7 @@ class TestPatient(SDKBaseTest):
             'interviews',
             'lab_reports',
             'medications',
+            'procedures',
             'protocol_overrides',
             'prescriptions',
             'reason_for_visits',
@@ -337,6 +342,7 @@ class TestPatient(SDKBaseTest):
             'interviews',
             'lab_reports',
             'medications',
+            'procedures',
             'protocol_overrides',
             'prescriptions',
             'reason_for_visits',
