@@ -14,6 +14,7 @@ from canvas_workflow_kit.patient_recordset import (
     PatientEventRecordSet,
     PatientPeriodRecordSet,
     PatientRecordSet,
+    ProcedureRecordSet,
     ProtocolOverrideRecordSet,
     PrescriptionRecordSet,
     ReferralReportRecordSet,
@@ -1086,7 +1087,7 @@ class TestBillingLineItemRecordSet(TestCase):
     def test_constants(self):
         tested = BillingLineItemRecordSet([])
         self.assertIsInstance(tested, BillingLineItemRecordSet)
-        self.assertEqual(['cpt', 'hcpcs'], tested.VALID_SYSTEMS)
+        self.assertEqual(['cpt', 'hcpcs', 'snomedct'], tested.VALID_SYSTEMS)
         self.assertEqual('created', tested.DATE_FIELD)
         self.assertEqual('billing_line_items', tested.PATIENT_FIELD)
         self.assertEqual('patient__key', tested.API_KEY_FIELD)
@@ -1370,6 +1371,7 @@ class TestMedicationRecordSet(TestCase):
         ]
         self.assertEqual(expected, MedicationRecordSet.item_to_codes(item))
 
+
 class TestPrescriptionRecordSet(TestCase):
 
     def test_constants(self):
@@ -1428,6 +1430,7 @@ class TestPrescriptionRecordSet(TestCase):
         ]
         self.assertEqual(expected, PrescriptionRecordSet.item_to_codes(item))
 
+
 class TestInterviewRecordSet(TestCase):
 
     def test_constants(self):
@@ -1658,6 +1661,65 @@ class TestImagingReportRecordSet(TestCase):
         self.assertEqual(expected, ImagingReportRecordSet.item_to_codes(item))
 
 
+class TestProcedureRecordSet(TestCase):
+
+    def test_constants(self):
+        tested = ProcedureRecordSet([])
+        self.assertIsInstance(tested, PatientRecordSet)
+        self.assertEqual(['cpt', 'snomedct'], tested.VALID_SYSTEMS)
+        self.assertEqual('procedures', tested.PATIENT_FIELD)
+        self.assertEqual('procedures', tested.API_UPDATE_FIELD)
+
+    def test_item_to_codes(self):
+        item = {
+            'codinx': [{
+                'system': '',
+                'code': 'cde113',
+                'display': 'The A'
+            }],
+            'coding': [
+                {
+                    'system': '',
+                    'code': 'cde123',
+                    'display': 'The A'
+                },
+                {
+                    'system': '',
+                    'code': 'cde124',
+                    'display': 'The B'
+                },
+                {
+                    'system': '',
+                    'code': 'cde125',
+                    'display': 'The C'
+                },
+            ],
+            'codiny': [{
+                'system': '',
+                'code': 'cde133',
+                'display': 'The A'
+            }],
+        }
+        expected = [
+            {
+                'system': '',
+                'code': 'cde123',
+                'display': 'The A'
+            },
+            {
+                'system': '',
+                'code': 'cde124',
+                'display': 'The B'
+            },
+            {
+                'system': '',
+                'code': 'cde125',
+                'display': 'The C'
+            },
+        ]
+        self.assertEqual(expected, PrescriptionRecordSet.item_to_codes(item))
+
+
 class TestProtocolOverrideRecordSet(TestCase):
 
     def test_constants(self):
